@@ -1,15 +1,10 @@
-from __future__ import with_statement
-
-try:
-    import queue
-except ImportError:
-    import Queue as queue
 import random
-import Pyro4
+from Pyro5.api import Proxy, SerializerBase
 from workitem import Workitem
 
-# we're using custom classes, so need to use pickle
-Pyro4.config.SERIALIZER = 'pickle'
+
+# For 'workitem.Workitem' we register a deserialization hook to be able to get these back from Pyro
+SerializerBase.register_dict_to_class("workitem.Workitem", Workitem.from_dict)
 
 NUMBER_OF_ITEMS = 40
 
@@ -18,7 +13,7 @@ def main():
     print("\nThis program will calculate Prime Factorials of a bunch of random numbers.")
     print("The more workers you will start (on different cpus/cores/machines),")
     print("the faster you will get the complete list of results!\n")
-    with Pyro4.core.Proxy("PYRONAME:example.distributed.dispatcher") as dispatcher:
+    with Proxy("PYRONAME:example.distributed.dispatcher") as dispatcher:
         placework(dispatcher)
         numbers = collectresults(dispatcher)
     printresults(numbers)
@@ -38,11 +33,12 @@ def collectresults(dispatcher):
     while len(numbers) < NUMBER_OF_ITEMS:
         try:
             item = dispatcher.getResult()
-            print("Got result: %s (from %s)" % (item, item.processedBy))
-            numbers[item.data] = item.result
-        except queue.Empty:
+        except ValueError:
             print("Not all results available yet (got %d out of %d). Work queue size: %d" %
                   (len(numbers), NUMBER_OF_ITEMS, dispatcher.workQueueSize()))
+        else:
+            print("Got result: %s (from %s)" % (item, item.processedBy))
+            numbers[item.data] = item.result
 
     if dispatcher.resultQueueSize() > 0:
         print("there's still stuff in the dispatcher result queue, that is odd...")
