@@ -1,21 +1,13 @@
-from __future__ import print_function
 import os
 import socket
 import sys
 from math import sqrt
+from Pyro5.api import SerializerBase, Proxy
+from workitem import Workitem
 
 
-try:
-    import queue
-except ImportError:
-    import Queue as queue
-import Pyro4
-
-if sys.version_info < (3, 0):
-    range = xrange
-
-# we're using custom classes, so need to use pickle
-Pyro4.config.SERIALIZER = 'pickle'
+# For 'workitem.Workitem' we register a deserialization hook to be able to get these back from Pyro
+SerializerBase.register_dict_to_class("workitem.Workitem", Workitem.from_dict)
 
 WORKERNAME = "Worker_%d@%s" % (os.getpid(), socket.gethostname())
 
@@ -24,7 +16,7 @@ def factorize(n):
     """simple algorithm to find the prime factorials of the given number n"""
 
     def isPrime(n):
-        return not [x for x in range(2, int(sqrt(n)) + 1) if n % x == 0]
+        return not any(x for x in range(2, int(sqrt(n)) + 1) if n % x == 0)
 
     primes = []
     candidates = range(2, n + 1)
@@ -45,13 +37,13 @@ def process(item):
 
 
 def main():
-    dispatcher = Pyro4.core.Proxy("PYRONAME:example.distributed.dispatcher")
+    dispatcher = Proxy("PYRONAME:example.distributed.dispatcher")
     print("This is worker %s" % WORKERNAME)
     print("getting work from dispatcher.")
     while True:
         try:
             item = dispatcher.getWork()
-        except queue.Empty:
+        except ValueError:
             print("no work available yet.")
         else:
             process(item)
